@@ -21,19 +21,18 @@
 #' @param size the sample size for drawing samples from N(0, 1)
 #' @param cl two different colors to annotate whether the confidence intervals
 #'   cover the true mean (\code{cl[1]}: no; \code{cl[2]}: yes)
-#' @param \dots other arguments passed to \code{\link[graphics]{plot.default}}
+#' @param \dots other arguments passed to \code{\link{plot.default}}
 #' @return A list containing \item{level }{confidence level} \item{size }{sample
 #'   size} \item{CI}{a matrix of confidence intervals for each sample}
 #'   \item{CR}{coverage rate}
-#' @author Yihui Xie <\url{http://yihui.name}>
+#' @author Yihui Xie
 #' @references George Casella and Roger L. Berger. \emph{Statistical Inference}.
-#' Duxbury Press, 2th edition, 2001.
+#'   Duxbury Press, 2th edition, 2001.
 #'
-#' \url{http://animation.yihui.name/mathstat:confidence_interval}
-#' @keywords dynamic dplot distribution
+#' @export
 #' @example inst/examples/conf.int-ex.R
-conf.int = function(level = 0.95, size = 50, cl = c("red", "gray"), ...) {
-  n = ani.options("nmax")
+conf.int = function(level = 0.95, size = 50, cl = c('red', 'gray'), ...) {
+  n = ani.options('nmax')
   d = replicate(n, rnorm(size))
   m = colMeans(d)
   z = qnorm(1 - (1 - level)/2)
@@ -44,24 +43,27 @@ conf.int = function(level = 0.95, size = 50, cl = c("red", "gray"), ...) {
   xax = pretty(1:n)
   for (i in 1:n) {
     dev.hold()
-    plot(1:n, ylim = rg, type = "n", xlab = "Samples", ylab = expression("CI: [" ~
-      bar(x) - z[alpha/2] * sigma/sqrt(n) ~ ", " ~ bar(x) +
-      z[alpha/2] * sigma/sqrt(n) ~ "]"), xaxt = "n", ...)
+    plot(
+      1:n, ylim = rg, type = 'n', xlab = 'Samples',
+      ylab = expression('CI: [' ~ bar(x) - z[alpha/2] * sigma/sqrt(n) ~ ', ' ~ bar(x) +
+                          z[alpha/2] * sigma/sqrt(n) ~ ']'), xaxt = 'n', ...)
     abline(h = 0, lty = 2)
     axis(1, xax[xax <= i])
-    arrows(1:i, y0[1:i], 1:i, y1[1:i], length = par("din")[1]/n * 0.5,
-           angle = 90, code = 3, col = cl[cvr[1:i] + 1])
+    arrows(
+      1:i, y0[1:i], 1:i, y1[1:i], length = par('din')[1]/n * 0.5,
+      angle = 90, code = 3, col = cl[cvr[1:i] + 1])
     points(1:i, m[1:i], col = cl[cvr[1:i] + 1])
-    legend("topright",
-           legend = format(c(i - sum(cvr[1:i]), sum(cvr[1:i])), width = nchar(n)),
-           fill = cl, bty = "n", ncol = 2)
-    legend("topleft",
-           legend = paste("coverage rate:", format(round(mean(cvr[1:i]), 3), nsmall = 3)),
-           bty = "n")
+    legend(
+      'topright', legend = format(c(i - sum(cvr[1:i]), sum(cvr[1:i])), width = nchar(n)),
+      fill = cl, bty = 'n', ncol = 2)
+    legend(
+      'topleft',
+      legend = paste('coverage rate:', format(round(mean(cvr[1:i]), 3), nsmall = 3)),
+      bty = 'n')
     ani.pause()
   }
   CI = cbind(y0, y1)
-  colnames(CI) = paste(round(c((1 - level)/2, 1 - (1 - level)/2), 2) * 100, "%")
+  colnames(CI) = paste(round(c((1 - level)/2, 1 - (1 - level)/2), 2) * 100, '%')
   rownames(CI) = 1:n
   invisible(list(level = level, size = size, CI = CI, CR = mean(cvr)))
 }
