@@ -15,9 +15,9 @@
 #' number of iterations \code{ani.options('nmax')} has not been reached.
 #' @param FUN a bivariate objective function to be minimized (variable names do
 #'   not have to be \code{x} and \code{y}); if the gradient argument \code{gr}
-#'   is \code{NULL}, \code{\link[stats]{deriv}} will be used to calculate the
-#'   gradient, in which case we should not put braces around the function body
-#'   of \code{FUN} (e.g. the default function is \code{function(x, y) x^2 + 2 *
+#'   is \code{NULL}, \code{\link{deriv}} will be used to calculate the gradient,
+#'   in which case we should not put braces around the function body of
+#'   \code{FUN} (e.g. the default function is \code{function(x, y) x^2 + 2 *
 #'   y^2})
 #' @param rg ranges for independent variables to plot contours; in a \code{c(x0,
 #'   y0, x1, y1)} form
@@ -28,8 +28,7 @@
 #' @param gr the gradient of \code{FUN}; it should be a bivariate function to
 #'   calculate the gradient (not the negative gradient!) of \code{FUN} at a
 #'   point \eqn{(x,y)}, e.g. \code{function(x, y) 2 * x + 4 * y}. If it is
-#'   \code{NULL}, R will use \code{\link[stats]{deriv}} to calculate the
-#'   gradient
+#'   \code{NULL}, R will use \code{\link{deriv}} to calculate the gradient
 #' @param len desired length of the independent sequences (to compute z values
 #'   for contours)
 #' @param interact logical; whether choose the starting values by cliking on the
@@ -45,29 +44,28 @@
 #'   reliable because the maximum number of iterations has been reached}
 #'   \item{gradient}{the gradient function of the objective function}
 #'   \item{persp}{a function to make the perspective plot of the objective
-#'   function; can accept further arguments from \code{\link[graphics]{persp}}
-#'   (see the examples below)}
+#'   function; can accept further arguments from \code{\link{persp}} (see the
+#'   examples below)}
 #' @note Please make sure the function \code{FUN} provided is differentiable at
 #'   \code{init}, what's more, it should also be 'differentiable' using
-#'   \code{\link[stats]{deriv}} if you do not provide the gradient function
-#'   \code{gr}.
+#'   \code{\link{deriv}} if you do not provide the gradient function \code{gr}.
 #'
 #'   If the arrows cannot reach the local minimum, the maximum number of
 #'   iterations \code{nmax} in \code{\link{ani.options}} may need to be
 #'   increased.
-#' @author Yihui Xie <\url{http://yihui.name}>
-#' @seealso \code{\link[stats]{deriv}}, \code{\link[graphics]{persp}},
-#'   \code{\link[graphics]{contour}}, \code{\link[stats]{optim}}
+#' @author Yihui Xie
+#' @seealso \code{\link{deriv}}, \code{\link{persp}}, \code{\link{contour}},
+#'   \code{\link{optim}}
 #' @references
 #' \url{http://vis.supstat.com/2013/03/gradient-descent-algorithm-with-r/}
-#' @keywords optimize dynamic dplot
+#' @export
 #' @example inst/examples/grad.desc-ex.R
 grad.desc = function(
   FUN = function(x, y) x^2 + 2 * y^2, rg = c(-3, -3, 3, 3), init = c(-3, 3),
   gamma = 0.05, tol = 0.001, gr = NULL, len = 50, interact = FALSE,
-  col.contour = "red", col.arrow = "blue", main
+  col.contour = 'red', col.arrow = 'blue', main
 ) {
-  nmax = ani.options("nmax")
+  nmax = ani.options('nmax')
   x = seq(rg[1], rg[3], length = len)
   y = seq(rg[2], rg[4], length = len)
   nms = names(formals(FUN))
@@ -82,11 +80,11 @@ grad.desc = function(
   }
   z = outer(x, y, FUN)
   xy = if (interact) {
-    contour(x, y, z, col = "red", xlab = nms[1], ylab = nms[2],
-            main = "Choose initial values by clicking on the graph")
+    contour(x, y, z, col = 'red', xlab = nms[1], ylab = nms[2],
+            main = 'Choose initial values by clicking on the graph')
     unlist(locator(1))
   } else init
-  newxy = xy - gamma * attr(grad(xy[1], xy[2]), "gradient")
+  newxy = xy - gamma * attr(grad(xy[1], xy[2]), 'gradient')
   gap = abs(FUN(newxy[1], newxy[2]) - FUN(xy[1], xy[2]))
   if (missing(main)) main = eval(substitute(expression(z == x), list(x = body(FUN))))
   i = 1
@@ -94,16 +92,19 @@ grad.desc = function(
     dev.hold()
     contour(x, y, z, col = col.contour, xlab = nms[1], ylab = nms[2], main = main)
     xy = rbind(xy, newxy[i, ])
-    newxy = rbind(newxy, xy[i + 1, ] -
-                    gamma * attr(grad(xy[i + 1, 1], xy[i + 1, 2]), "gradient"))
+    newxy = rbind(newxy, xy[i + 1, ] - gamma * attr(grad(xy[i + 1, 1], xy[i + 1, 2]), 'gradient'))
     arrows(xy[1:i, 1], xy[1:i, 2], newxy[1:i, 1], newxy[1:i, 2],
-           length = par("din")[1] / 50, col = col.arrow)
+           length = par('din')[1] / 50, col = col.arrow)
     gap = abs(FUN(newxy[i + 1, 1], newxy[i + 1, 2]) - FUN(xy[i + 1, 1], xy[i + 1, 2]))
     ani.pause()
     i = i + 1
     if (i > nmax) warning('Maximum number of iterations reached!')
   }
-  invisible(list(par = newxy[i - 1, ], value = FUN(newxy[i - 1, 1], newxy[i - 1, 2]),
-                 iter = i - 1, gradient = grad,
-                 persp = function(...) persp(x, y, z, ...)))
+  invisible(
+    list(
+      par = newxy[i - 1, ], value = FUN(newxy[i - 1, 1], newxy[i - 1, 2]),
+      iter = i - 1, gradient = grad,
+      persp = function(...) persp(x, y, z, ...)
+    )
+  )
 }
