@@ -8,29 +8,29 @@
 #'   (recycled if necessary).
 #' @param p.col,p.cex different colors /magnification rate to annotate the
 #'   population and the sample
-#' @param \dots other arguments passed to \code{\link[graphics]{rect}} to
-#'   annotate the ``strata''
+#' @param \dots other arguments passed to \code{\link{rect}} to annotate the
+#'   ``strata''
 #' @return None (invisible `\code{NULL}').
-#' @author Yihui Xie <\url{http://yihui.name}>
-#' @seealso \code{\link[base]{sample}}, \code{\link{sample.simple}},
+#' @author Yihui Xie
+#' @seealso \code{\link{sample}}, \code{\link{sample.simple}},
 #'   \code{\link{sample.cluster}}, \code{\link{sample.ratio}},
 #'   \code{\link{sample.system}}
-#' @references \url{http://animation.yihui.name/samp:stratified_sampling}
-#' @keywords distribution dynamic
+#' @export
 #' @example inst/examples/sample.strat-ex.R
-sample.strat = function(pop = ceiling(10 * runif(10, 0.5, 1)),
-                        size = ceiling(pop * runif(length(pop), 0, 0.5)),
-                        p.col = c("blue", "red"), p.cex = c(1, 3), ...) {
+sample.strat = function(
+  pop = ceiling(10 * runif(10, 0.5, 1)), size = ceiling(pop * runif(length(pop), 0, 0.5)),
+  p.col = c('blue', 'red'), p.cex = c(1, 3), ...
+) {
   if (any(size > pop))
-    stop("sample size must be smaller than population")
+    stop('sample size must be smaller than population')
   ncol = max(pop)
   nrow = length(pop)
   size = rep(size, length = nrow)
-  nmax = ani.options("nmax")
+  nmax = ani.options('nmax')
   for (i in 1:nmax) {
     dev.hold()
-    plot(1, axes = FALSE, ann = FALSE, type = "n", xlim = c(0.5, ncol + 0.5),
-         ylim = c(0.5, nrow + 0.5), xaxs = "i", yaxs = "i", xlab = "", ylab = "")
+    plot(1, axes = FALSE, ann = FALSE, type = 'n', xlim = c(0.5, ncol + 0.5),
+         ylim = c(0.5, nrow + 0.5), xaxs = 'i', yaxs = 'i', xlab = '', ylab = '')
     rect(rep(0.5, nrow), seq(0.5, nrow, 1),
          rep(ncol + 0.5, nrow), seq(1.5, nrow + 1, 1), lwd = 1, ...)
     for (j in 1:nrow) {
